===============================
Interacting Hysteron Simulation
===============================


Event-based simulation of hysterons (hysteretic 2-state subsystems).

Written by Nathan C. Keim, based on algorithms and research by Joseph R. Paulsen and Nathan C. Keim.

The core algorithm is in `hysteron/hysteron.py`.

For instructions, see the Jupyter notebook `hysteron-howto.ipynb`.

* Free software: Apache Software License 2.0
* Documentation: https://hysteron.readthedocs.io.

If you use this software in published research, please cite `this paper`_:
"Multiperiodic orbits from interacting soft spots in cyclically-sheared amorphous solids." Nathan C. Keim, Joseph D. Paulsen. Science Advances 7, eabg7685 (2021). 
DOI: 10.1126/sciadv.abg7685

Development of this software was supported in part by NSF grant no. DMR-1708870 (to N.C.K.).


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _`this paper`: https://advances.sciencemag.org/content/7/33/eabg7685
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
